#!/bin/sh
set -e    # exit on error (except commands bracketed with "set +e ... set -e")
#
# Script to set up and run Gmaj for the gene-conversion pipeline,
# showing many-to-many orthologs instead of conversion evidence.
# It uses the exons2underlays tool in the package's bin directory.
#

JAR=../gmaj.jar
CHAIN_DIR=ortho.d/ch_pair.d
MTM_DIR=ortho.d/many-to-many-ortho.d
EXON_DIR=annot.d
E2U="../bin/exons2underlays -laj -intron Clear -fexon"
#GC_FILE=./all.gc
PARAM_FILE=./gmaj.param
PREFS_FILE=./gmaj.prefs
HEAP_MB=200
SCRIPT=`echo $0 | sed -e 's;.*/;;'`    # path removed for messages
TITLE="Many-to-many orthologs vs. all chained alignments"
COLOR=LightGray

# ---- get arguments ----

if [ $# -ne 2 ]; then
	echo "Usage:  $SCRIPT refseq_name seq2_name"
	exit 1
fi

REFNAME=$1
SEQ2NAME=$2

# ---- set up data files ----

if [ -h chained.maf ]; then    # symlink
	rm chained.maf
fi
if [ ! -e chained.maf ]; then
	ln -s $CHAIN_DIR/$REFNAME.$SEQ2NAME.maf chained.maf
fi

if [ -h many-to-many.maf ]; then    # symlink
	rm many-to-many.maf
fi
if [ ! -e many-to-many.maf ]; then
	ln -s $MTM_DIR/$REFNAME.$SEQ2NAME.maf many-to-many.maf
fi

for seq in $REFNAME $SEQ2NAME; do
	if [ ! $COLOR ]; then
		:    # no underlays
	elif [ -f $EXON_DIR/$seq.underlays ]; then
		echo "Using existing underlay file $EXON_DIR/$seq.underlays"
	elif [ -f $EXON_DIR/$seq.codex ]; then
		echo "Creating underlay file $EXON_DIR/$seq.underlays from exons"
		$E2U $COLOR $EXON_DIR/$seq.codex | sed -e 's;\<intron\>;gene;g' > $EXON_DIR/$seq.underlays
	else
		echo "No annotations available in $EXON_DIR for $seq"
	fi
done

# ---- write parameters file ----

rm -f $PARAM_FILE
seqno=0
fn=

echo "#:gmaj"                                    > $PARAM_FILE
echo                                             >> $PARAM_FILE
echo "title = \"$TITLE\""                        >> $PARAM_FILE
echo "alignfile = many-to-many.maf chained.maf"  >> $PARAM_FILE
echo "refseq = $REFNAME"                         >> $PARAM_FILE
echo                                             >> $PARAM_FILE
for seq in $REFNAME $SEQ2NAME; do
	echo "seq $seqno:"                          >> $PARAM_FILE
	seqno=`expr $seqno + 1`
	echo "seqname   = $seq"                     >> $PARAM_FILE
	fn=$EXON_DIR/$seq.codex; [ -f $fn ] || fn=
	echo "exons     = $fn"                      >> $PARAM_FILE
	fn=$EXON_DIR/$seq.underlays; ([ -f $fn ] && [ $COLOR ]) || fn=
	echo "underlays = $fn"                      >> $PARAM_FILE
	echo                                        >> $PARAM_FILE
done

# ---- run Gmaj with extra heap space, and user prefs if present ----

if [ -f $PREFS_FILE ]; then
	exec java -Xmx${HEAP_MB}m -jar $JAR -prefs $PREFS_FILE $PARAM_FILE
else
	exec java -Xmx${HEAP_MB}m -jar $JAR $PARAM_FILE
fi

